@@ -41,18 +41,6 @@ func TestListDevicesWithErr(t *testing.T) {
 	assert.Equal(t, "loading mount points: open /xxxyyy: no such file or directory", err.Error())
 }
 
-func TestLogError(t *testing.T) {
-	out, err := runApp(
-		&Flags{LogFile: "/xyzxyz"},
-		[]string{},
-		false,
-		testdev.DevicesInfoGetterMock{},
-	)
-
-	assert.Empty(t, out)
-	assert.Contains(t, err.Error(), "permission denied")
-}
-
 func TestOutputFileError(t *testing.T) {
 	out, err := runApp(
 		&Flags{LogFile: "/dev/null", OutputFile: "/xyzxyz"},
