@@ -13,34 +13,6 @@ import (
 	"github.com/rivo/tview"
 )
 
-const helpText = `    [::b]up/down, k/j    [white:black:-]Move cursor up/down
-  [::b]pgup/pgdn, g/G    [white:black:-]Move cursor top/bottom
- [::b]enter, right, l    [white:black:-]Go to directory/device
-         [::b]left, h    [white:black:-]Go to parent directory
-
-               [::b]r    [white:black:-]Rescan current directory
-               [::b]/    [white:black:-]Search items by name
-               [::b]a    [white:black:-]Toggle between showing disk usage and apparent size
-               [::b]B    [white:black:-]Toggle bar alignment to biggest file or directory
-               [::b]c    [white:black:-]Show/hide file count
-               [::b]m    [white:black:-]Show/hide latest mtime
-               [::b]b    [white:black:-]Spawn shell in current directory
-               [::b]q    [white:black:-]Quit gdu
-               [::b]Q    [white:black:-]Quit gdu and print current directory path
-
-Item under cursor:
-               [::b]d    [white:black:-]Delete file or directory
-               [::b]e    [white:black:-]Empty file or directory
-               [::b]v    [white:black:-]Show content of file
-               [::b]o    [white:black:-]Open file or directory in external program
-               [::b]i    [white:black:-]Show info about item
-
-Sort by (twice toggles asc/desc):
-               [::b]n    [white:black:-]Sort by name (asc/desc)
-               [::b]s    [white:black:-]Sort by size (asc/desc)
-               [::b]C    [white:black:-]Sort by file count (asc/desc)
-               [::b]M    [white:black:-]Sort by mtime (asc/desc)`
-
 // UI struct
 type UI struct {
 	*common.UI
@@ -79,6 +51,7 @@ type UI struct {
 	currentItemNameMaxLen   int
 	defaultSortBy           string
 	defaultSortOrder        string
+	markedRows              map[int]struct{}
 }
 
 // Option is optional function customizing the bahaviour of UI
@@ -119,6 +92,7 @@ func CreateUI(
 		currentItemNameMaxLen:   70,
 		defaultSortBy:           "size",
 		defaultSortOrder:        "desc",
+		markedRows:              make(map[int]struct{}),
 	}
 	for _, o := range opts {
 		o(ui)
@@ -237,6 +211,7 @@ func (ui *UI) fileItemSelected(row, column int) {
 
 	ui.currentDir = selectedDir.(*analyze.Dir)
 	ui.hideFilterInput()
+	ui.markedRows = make(map[int]struct{})
 	ui.showDir()
 
 	if selectedDir == origDir.GetParent() {
@@ -270,6 +245,14 @@ func (ui *UI) deviceItemSelected(row, column int) {
 }
 
 func (ui *UI) confirmDeletion(shouldEmpty bool) {
+	if len(ui.markedRows) > 0 {
+		ui.confirmDeletionMarked(shouldEmpty)
+	} else {
+		ui.confirmDeletionSelected(shouldEmpty)
+	}
+}
+
+func (ui *UI) confirmDeletionSelected(shouldEmpty bool) {
 	row, column := ui.table.GetSelection()
 	selectedFile := ui.table.GetCell(row, column).GetReference().(fs.Item)
 	var action string
